//
//  ViewController.swift
//  BasicS3
//

import Cocoa

class ViewController: NSViewController {
    var s3 = BasicS3(region: "us-east-1", bucket: "www.stephenlindholm.com")
    var credentialsSet: Bool = false

    @IBOutlet weak var idTextField: NSTextField!
    @IBOutlet weak var keyTextField: NSTextField!
    @IBOutlet weak var objectTextField: NSTextField!
    
    func initializeCredentials () -> Bool {
        let id = idTextField.stringValue
        let key = keyTextField.stringValue

        if id != "" && key != "" {
            s3.setAwsCredentials(awsID: id, awsKey: key)
        }
        else if !s3.loadAwsCredentials() {
            NSLog("Could not load credentials")
            return false
        }

        credentialsSet = true
        return true
    }
    
    @IBAction func getTest(_ sender: NSButton) {
        if !credentialsSet && !initializeCredentials() { return }
        if objectTextField.stringValue == "" { return }
        
        let obj = s3.getObject(objectPath: objectTextField.stringValue)
        let objString:String? = obj?.data != nil ? String(data: obj!.data!, encoding: String.Encoding.utf8) : nil
        print("\(objString ?? "nil") - \(obj?.etag ?? "nil") - \(obj?.lastModified?.description ?? "nil") - \(obj?.name ?? "nil")")
    }
    
    @IBAction func putTest(_ sender: NSButton) {
        if !credentialsSet && !initializeCredentials() { return }
        let objectPath = objectTextField.stringValue
        if objectPath == "" { return }

        let data = ("Test data for path " + objectPath).data(using: String.Encoding.utf8)!
        let success = s3.putObject(objectPath: objectPath, data: data, contentType: "text/plain")
        print(success ? "put succeeded" : "put failed")
    }
    
    @IBAction func headTest(_ sender: NSButton) {
        if !credentialsSet && !initializeCredentials() { return }
        if objectTextField.stringValue == "" { return }
        
        let obj = s3.headObject(objectPath: objectTextField.stringValue)
        let objString:String? = obj?.data != nil ? String(data: obj!.data!, encoding: String.Encoding.utf8) : nil
        print("\(objString ?? "nil") - \(obj?.etag ?? "nil") - \(obj?.lastModified?.description ?? "nil") - \(obj?.name ?? "nil")")
    }
    
    @IBAction func deleteTest(_ sender: NSButton) {
        if !credentialsSet && !initializeCredentials() { return }
        if objectTextField.stringValue == "" { return }
        
        _ = s3.deleteObject(objectPath: objectTextField.stringValue)
    }
    
    @IBAction func listTest(_ sender: NSButton) {
        if !credentialsSet && !initializeCredentials() { return }
        
        print("\(s3.listObjects()?.recursiveObjectNames().joined(separator: "\n") ?? "nil")")
    }
    
    @IBAction func deleteKeychain(_ sender: NSButton) {
        _ = s3.deleteAwsCredentials()
    }
}

